 /*+---------------------------------------------------------------------+ 
   |          S A S   S A M P L E   L I B R A R Y                        | 
   |    NAME: SGMPEOSM                                                   | 
   |   TITLE: SGMPEOSM Choropleth, OSM, and Esri Map of NV County        | 
   |          Populations                                                | 
   |  PRODUCT: BASE                                                      | 
   |  SYSTEM: ALL                                                        | 
   |    KEYS: GRAPHICS CHOROMAP SGMAPOSM ESRI                            | 
   |   PROCS: SGMAP                                                      | 
   |    DATA: EXTERNAL                                                   |
   | RELEASE: SAS 9.4M5 and later releases                               |   
   |                                                                     | 
   | SUPPORT: GRAPHICS STAFF                CREATED: AUG2017             | 
   | REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                       | 
   +---------------------------------------------------------------------+*/ 

/* Set base name for the output image files. */ 
%let basename=Nevada_pop;
 
/* Set the graphics environment */         
ods graphics / reset outputfmt=png width=5.5in height=4.2in;
 
/* Retrieve all Nevada city locations. 
      Use unprojected long/lat coordinates because the 
      projected x/y values in the map polygonal data and in the city 
      location data use different projections which means the cities 
      do not align with the county polygons. */ 
data city_loc (label='Nevada Cities' 
               keep=county city city2 lat long county_name); 
  set mapsgfk.uscity_all(where=(state=32)); 
run; 
 
proc sort data=city_loc; 
  by city2; 
run; 
 
/* Create city population response data for bubbles. */ 
data city_pop (label='Nevada County Seat Populations'); 
  length city $65 city2 $55; 
  infile datalines dlm=','; 
  input city population_city county; 
  label city            = 'County Seat' 
        city2           = 'Normalized city name' 
        population_city = 'City Population' 
        county          = 'County FIPS Code'; 
  city2 = upcase(compress(city)); 
cards; 
Fallon, 8458, 1 
Las Vegas, 623747, 3 
Minden, 3180, 5 
Elko, 20279, 7 
Goldfield, 443, 9 
Eureka, 487, 11 
Winnemucca, 7887, 13 
Battle Mountain, 3276, 15 
Pioche, 911, 17 
Yerington, 3064, 19 
Hawthorne, 3095, 21 
Tonopah, 2360 , 23 
Lovelock, 1878, 27 
Virginia City, 717, 29 
Reno, 241445, 31 
Ely, 4134, 33 
Carson City, 54521, 510 
; 
 
proc sort data=city_pop; 
  by city2; 
run; 
 
/* Combine city locations for BUBBLE placement 
    with response data for BUBBLE sizes. 
    Keep only county seat obs. 
   This is the PLOTDATA= data set. */ 
data city_pop_loc; 
  merge city_pop (in=a) city_loc; 
  by city2; 
  if a; 
run; 
 
/* Retrieve Nevada county boundaries for choropleth map. 
   You cannot plot these existing X/Y values with the X/Y 
   values in the county map data used below because the 
   two data sets use different projections. The city bubbles 
   would not align with the county boundaries. Avoid this by 
   plotting the unprojected LONG/LAT values. 
   Rename LONG/LAT variables to be X/Y. 
   This is the MAPDATA= data set. */ 
data nevada; 
  set mapsgfk.us_counties (where=(state=32) 
                           drop=x y 
                           rename=(long=x lat=y)); 
run; 
 
 
/* Draw choro map using MAPSGFK base map of Nevada 
   county boundaries with bubbles at each county seat. 
   Bubbles are sized based on city populations. */ 
ods graphics / height=680px width=1024px 
                        imagename="&basename._MAPSGFK" 
                        imagefmt=png; 
title 'Nevada Populations Using MAPSGFK Map'; 
proc sgmap                          /* Invoke procedure  */ 
           mapdata=nevada     /* County boundary data 
                                                for CHOROMAP polygons */ 
           plotdata=city_pop_loc /* Bubble response & location data */ 
           des='Nevada';             /* Description */ 
  choromap / mapid=county;  /* Var in MAPDATA data set for 
                                                   county boundaries */ 
  bubble x=long y=lat 
         size=population_city / 
            name='cities'                /* Link name to legend */ 
            datalabel=city            /* PLOTDATA var to label BUBBLES */ 
            datalabelattrs=(color=black    /* BUBBLE label color */ 
                            size=0.15in  /* BUBBLE label font size */ 
                            style=italic); /* BUBBLE label font style */ 
  keylegend 'cities';                  /* Show BUBBLES in legend */ 
run; 
 
/* Plot bubbles on Open Street Map base. */ 
ods graphics / imagename="&basename._OSM"; 
title 'Nevada Populations Using Open Street Map'; 
proc sgmap                          /* Invoke procedure */ 
           plotdata=city_pop_loc  /* Bubble response & location data */ 
           des='Nevada'; 
  openstreetmap;                    /* Use OSM base map */ 
  bubble x=long y=lat 
         size=population_city / 
               name='cities'           /* Link name to legend */ 
               datalabel=city          /* PLOTDATA var to label BUBBLES */ 
/* BUBBLE label parameters */ 
               datalabelattrs=(color=black 
                               size=0.15in 
                               style=italic); 
  keylegend 'cities'; 
run; 
 
/* Plot bubbles on Esri Map base. */ 
ods graphics / imagename="&basename._Esri"; 
title 'Nevada Populations Using Esri Map'; 
proc sgmap                                 /* Invoke procedure  */ 
           plotdata=city_pop_loc           /* Bubble response & location data */ 
           des='Nevada';                   /* Description */ 
/* Specify in url= the Esri base map you want to use. */ 
esrimap 
url='http://services.arcgisonline.com/arcgis/rest/services/World_Physical_Map' 
; 
  bubble x=long y=lat 
         size=population_city / 
            name='cities'                  /* Link name to legend */ 
            datalabel=city                 /* PLOTDATA var to label BUBBLES */ 
            datalabelattrs=(color=black    /* BUBBLE label color */ 
                            size=0.15in    /* BUBBLE label font size */ 
                            style=italic);   /* BUBBLE label font style */ 
  keylegend 'cities';                    /* Show BUBBLES in legend */ 
run; 

/* Reset the graphics environment */
ods graphics / reset;
title;
