  /*+--------------------------------------------------------------------+ 
   |          S A S   S A M P L E   L I B R A R Y                        | 
   |    NAME: SGMPNVB2                                                   | 
   |   TITLE: SGMPNVB2 Nevada County Seats and Populations-Bubble Plot   | 
   |                                                                     | 
   |  PRODUCT: BASE                                                      | 
   |  SYSTEM: ALL                                                        | 
   |    KEYS: GRAPHICS CHOROMAP SGMAP BUBBLE                             | 
   |   PROCS: SGMAP                                                      | 
   |    DATA: INTERNAL                                                   |
   | RELEASE: SAS 9.4M5 and later releases                               |   
   |                                                                     | 
   | SUPPORT: GRAPHICS STAFF                 CREATED: AUG2017            |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                   | 
   +---------------------------------------------------------------------+*/ 
 
/* Set the graphics environment */ 
ods graphics / imagefmt=png width=6in height=5in;

/* Open the ODS HTML5 destination */
ods _all_ close;
ods html5 path="." file="sgmpnvb2.html" options(bitmap_mode="inline");
 
/* Plot where BUBBLES are county seat populations and 
      map polygons denote county population. Retrieve all Nevada city
      locations. 
    Note: 
          You cannot plot these existing X/Y values with 
           the X/Y values in the county map data used below 
           because the two data sets use different projections. 
           The city bubbles would not align with the 
           county boundaries. 
           Avoid this by plotting the unprojected LONG/LAT values. 
          Rename LONG/LAT variables to be X/Y. */ 
data city_xy (label='Nevada Cities' 
             keep=county city city2 x y county_name); 
  set mapsgfk.uscity_all(where=(state=32) drop=x y 
                         rename=(long=x lat=y)); 
run; 
 
proc sort data=city_xy; 
  by city2; 
run; 
 
/* Create response data for city bubbles. */ 
data city_pop (label='Nevada County Seat Populations'); 
  length city $65 city2 $55; 
  infile datalines dlm=','; 
  input city population_city county; 
  label city            = 'County Seat' 
        city2           = 'Normalized city name' 
        population_city = 'City Population' 
        county          = 'County FIPS Code'; 
  city2 = upcase(compress(city)); 
cards; 
Fallon, 8458, 1 
Las Vegas, 623747, 3 
Minden, 3180, 5 
Elko, 20279, 7 
Goldfield, 443, 9 
Eureka, 487, 11 
Winnemucca, 7887, 13 
Battle Mountain, 3276, 15 
Pioche, 911, 17 
Yerington, 3064, 19 
Hawthorne, 3095, 21 
Tonopah, 2360 , 23 
Lovelock, 1878, 27 
Virginia City, 717, 29 
Reno, 241445, 31 
Ely, 4134, 33 
Carson City, 54521, 510 
; 
 
proc sort data=city_pop; 
  by city2; 
run; 
 
/* Combine city locations with response data for bubbles. 
      Keep only the county seats. */ 
data city_pop_xy; 
  merge city_pop (in=a) city_xy; 
  by city2; 
  if a; 
run; 
 
/* Create response data for county polygons. */ 
data county_pop (label='Nevada Counties'); 
  length county_name $55; 
  infile datalines dlm=','; 
  state=32; 
  input county_name county population_county; 
  label state            = 'State FIPS Code' 
        county_name       = 'County Name' 
        county            = 'County FIPS Code' 
        population_county = '2010 Census County Population' 
        group             = 'Population range' 
; 
 
/* Add five population ranges as groups to map response data. */ 
  if      population_county > 100000 then group='Greater than 100,000'; 
  else if population_county > 10000  then group='10,000 - 100,000'; 
  else if population_county > 5000   then group='5,000 - 10,000'; 
  else if population_county > 1000   then group='1,000 - 5,000'; 
  else                                    group='Less than 1,000'; 
cards; 
Churchill, 1, 24877 
Clark, 3, 2069681 
Douglas, 5, 47710 
Elko, 7, 52766 
Esmeralda, 9, 783 
Eureka, 11, 1987 
Humboldt, 13, 17019 
Lander, 15, 5775 
Lincoln, 17, 5036 
Lyon, 19, 52585 
Mineral, 21, 4772 
Nye, 23, 43946 
Pershing, 27, 6753 
Storey, 29, 3987 
Washoe, 31, 446903 
White Pine, 33, 10030 
Carson City, 510, 54521 
; 
 
 proc sort data=county_pop; 
   by population_county; 
 run; 
 
/*--- Create Graph style for county polygon colors. */ 
proc template; 
  define Style Styles.map; parent = styles.listing; 
    style GraphColors from graphcolors / 
          "gdata5" = cx2f2f5f 
          "gdata4" = cx4f4f7f 
          "gdata3" = cx5f5f9f 
          "gdata2" = cx9f9fdf 
          "gdata1" = cxdfdfff; 
   end; 
 run; 
 
/* Retrieve county boundaries for the choropleth map. */ 
data nevada; 
  set mapsgfk.us_counties(where=(state=32) 
                          drop=x y 
                          rename=(long=x lat=y)); 
run; 
 
title; 
proc sgmap mapdata=nevada /* Map polygon geometry     */ 
           maprespdata=county_pop /* Map polygon response data   */ 
           plotdata=city_pop_xy    /* Bubble response & location data */ 
           des='Nevada'; 
  title 'Nevada County Seats and Populations'; 
  choromap group / mapid=county id=county name='counties'; 
  bubble x=x y=y size=population_city / name='cities' datalabel=city 
                                        datalabelattrs=(color=cyan 
                                                        size=9 
                                                        style=italic); 
  keylegend 'counties' / title='County Population'; 
  keylegend 'cities'   / ; 
run; 

/* Close the ODS HTML5 destination. */
ods html5 close;
ods html;
 
/* Reset the graphics environment */
ods graphics / reset;
title;
